pub struct Image { /* private fields */ }Implementations
Sourceimpl Image
impl Image
Sourcepub fn new(width: u32, height: u32) -> Self
pub fn new(width: u32, height: u32) -> Self
Creates a new image with the given width and height.
Sourcepub fn from_data(
width: u32,
height: u32,
data: Vec<u32>,
) -> Result<Self, String>
pub fn from_data( width: u32, height: u32, data: Vec<u32>, ) -> Result<Self, String>
Create a new image from a boxed slice of colors
Sourcepub fn from_path<P: AsRef<Path>>(path: P) -> Result<Self, String>
pub fn from_path<P: AsRef<Path>>(path: P) -> Result<Self, String>
Load an image from file path. Supports BMP and PNG
pub fn data(&self) -> &[u32]
pub fn data_mut(&mut self) -> &mut [u32]