pub struct String16 { /* private fields */ }Expand description
A UTF-16 encoded, growable string.
Examples
let mut string16 = String16::from(“Übung”); string16.push(‘ä’);
Implementations
Sourceimpl String16
impl String16
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length of this String16, in bytes.
Examples
Basic usage:
let a = String16::from(“Übung”);
assert_eq!(a.len(), 5);
Sourcepub fn as_bytes(&self) -> &[u16]
pub fn as_bytes(&self) -> &[u16]
Returns a slice of u16s bytes that were attempted to convert to a String.
Sourcepub fn as_bytes_mut(&mut self) -> &mut [u16]
pub fn as_bytes_mut(&mut self) -> &mut [u16]
Returns a mutable slice of u16s bytes that were attempted to convert to a String.
Sourcepub fn insert_str(&mut self, idx: usize, string: &str)
pub fn insert_str(&mut self, idx: usize, string: &str)
Inserts a string slice into this String16 at a byte position.
Sourcepub fn remove(&mut self, idx: usize)
pub fn remove(&mut self, idx: usize)
Removes a char from this String16 at a byte position and returns it.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if this String16 has a length of zero, and false otherwise.
Sourcepub fn ends_with(&self, pat: &str) -> bool
pub fn ends_with(&self, pat: &str) -> bool
Returns true if this String16 ends with the given string slice, or false otherwise.